from minio import Minio


class MinioUtil(Minio):
    def __init__(self, bucket=None, *args, **kwargs):
        super(MinioUtil, self).__init__(*args, **kwargs)
        self.bucket = bucket
        self.create_bucket(self.bucket)

    def create_bucket(self, bucket):
        found = self.bucket_exists(bucket)
        if not found:
            self.make_bucket(bucket)

    def upload_file(self, src, dst, bucket=None):
        bucket = self.__get_bucket(bucket)
        self.fput_object(bucket, dst, src)

    def minio_utils(self, file, bucket=None):
        bucket = self.__get_bucket(bucket)
        self.remove_object(bucket, file)

    def __get_bucket(self, bucket):
        return bucket if bucket else self.bucket



import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="pl-minio-callback",
    version="1.0.1",
    author="Daniel Garcia Pulpeiro",
    author_email="danielgarciapulpeiro@gmail.com",
    description="Callback prepared to log checkpoints to minio server.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/dpulpeiro/pl-minio-callback",
    project_urls={
        "Bug Tracker": "https://github.com/dpulpeiro/pl-minio-callback/issues",

    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Topic :: Scientific/Engineering :: Artificial Intelligence",
        "Topic :: System :: Logging",
    ],
    install_requires=[
        "pytorch-lightning"
    ],
    package_dir={"": "src"},
    packages=setuptools.find_packages(where="src"),
    python_requires=">=3.6",
)